@@ -13,7 +13,7 @@ from rdkit import Chem
 from rdkit.Chem import AllChem
 from jpype import isJVMStarted, startJVM, getDefaultJVMPath, JPackage, types as jtypes
 
-from .utils import parse_numeric, parse_numeric_to_null
+from .utils import parse_numeric, parse_numeric_to_null, install_jre
 
 
 class Descriptor(ABC):
@@ -34,6 +34,8 @@ class Descriptor(ABC):
 
     def _load_resources(self):
         """Load all resources required for the descriptor calculation."""
+        # Ensure JRE available
+        jre_dir = install_jre()
         if not isJVMStarted():
             # Path to the PaDEL java library
             padel_path = os.path.join(__file__, os.pardir, 'PaDEL-Descriptor', 'lib', 'libPaDEL-Descriptor.jar')
@@ -42,7 +44,7 @@ class Descriptor(ABC):
             # Platform dependent java classpath separator
             separator = ':' if sys.platform == 'unix' else ';'
             # Start JVM
-            startJVM(getDefaultJVMPath(), "-ea", f"-Djava.class.path={padel_path}{separator}{epadel_path}")
+            startJVM(jre_dir, "-ea", f"-Djava.class.path={padel_path}{separator}{epadel_path}")
         # Java modules to be accessed
         self.padel = JPackage('libpadeldescriptor')
         self.epadel = JPackage('extendedlibpadeldescriptor')
@@ -633,17 +635,6 @@ class CDK_KappaShapeIndicesDescriptor(Descriptor):
         if not hasattr(self, '_descriptor'):
             self._descriptor = self.padel.CDK_KappaShapeIndicesDescriptor()
         return self._descriptor
-#
-#
-# class CDK_KierHallSmartsDescriptor(Descriptor):
-#     def __init__(self):
-#         super().__init__(False)
-#
-#     @property
-#     def descriptor(self):
-#         if not hasattr(self, '_descriptor'):
-#             self._descriptor = self.padel.CDK_KierHallSmartsDescriptor()
-#         return self._descriptor
 
 
 class CDK_LargestChainDescriptor(Descriptor):
@@ -1109,40 +1100,6 @@ class eCDK_AtomPairs2DFingerprintCount(Descriptor):
         return self._descriptor
 
 
-# class eCDK_LingoFingerprinter(Descriptor):
-#     @property
-#     def descriptor(self):
-#         if not hasattr(self, '_descriptor'):
-#             self._descriptor = self.epadel.eCDK_LingoFingerprinter()
-#         return self._descriptor
-#
-#     def set_params(self, params: Dict[str, int] = {'substring_length': 4}):
-#         default = {'substring_length': 4}
-#         default.update(params)
-#         self._descriptor = self.epadel.eCDK_ExtendedFingerprinter(default['substring_length'])
-#
-#
-# class eCDK_ShortestPathFingerprinter(Descriptor):
-#     @property
-#     def descriptor(self):
-#         if not hasattr(self, '_descriptor'):
-#             self._descriptor = self.epadel.eCDK_ShortestPathFingerprinter()
-#         return self._descriptor
-#
-#
-# class eCDK_SignatureFingerprinter(Descriptor):
-#     @property
-#     def descriptor(self):
-#         if not hasattr(self, '_descriptor'):
-#             self._descriptor = self.epadel.eCDK_SignatureFingerprinter()
-#         return self._descriptor
-#
-#     def set_params(self, params: Dict[str, int] = {'depth': 1}):
-#         default = {'depth': 1}
-#         default.update(params)
-#         self._descriptor = self.epadel.eCDK_ExtendedFingerprinter(default['depth'])
-#
-#
 _descs_2D = [CDK_AcidicGroupCountDescriptor,
              CDK_ALOGPDescriptor,
              CDK_APolDescriptor,
@@ -1183,7 +1140,6 @@ _descs_2D = [CDK_AcidicGroupCountDescriptor,
              CDK_HybridizationRatioDescriptor,
              CDK_InformationContentDescriptor,
              CDK_KappaShapeIndicesDescriptor,
-             # CDK_KierHallSmartsDescriptor,
              CDK_LargestChainDescriptor,
              CDK_LargestPiSystemDescriptor,
              CDK_LongestAliphaticChainDescriptor,
@@ -1233,9 +1189,6 @@ _fingerprints = [eCDK_Fingerprinter,
                  eCDK_SubstructureFingerprintCount,
                  eCDK_KlekotaRothFingerprintCount,
                  eCDK_AtomPairs2DFingerprintCount,
-                 # eCDK_LingoFingerprinter,
-                 # eCDK_ShortestPathFingerprinter,
-                 # eCDK_SignatureFingerprinter
                  ]
 
 Fingerprint = _fingerprints[0]
@@ -1250,6 +1203,3 @@ AtomPairs2DFingerprint = _fingerprints[8]
 SubstructureFingerprintCount = _fingerprints[9]
 KlekotaRothFingerprintCount = _fingerprints[10]
 AtomPairs2DFingerprintCount = _fingerprints[11]
-# LingoFingerprint = _fingerprints[12]
-# ShortestPathFingerprint = _fingerprints[13]
-# SignatureFingerprint = _fingerprints[14]
